@@ -9,27 +9,27 @@
 import logging
 from dataclasses import dataclass
 from enum import Enum, unique
+from typing import TypeAlias
 
 from aiohttp import hdrs
 from http_tools import AbmServiceConnector
 from init_helpers.dict_to_dataclass import dict_to_dataclass
+from yarl import URL
 
 logger = logging.getLogger(__name__)
 
 
 def construct_origin_from_referer(referer: str) -> str:
-    prefix, path = referer.split("://", 1)
-    return f"{prefix}://{path.split('/')[0]}"
+    return str(URL(referer).origin())
 
 
-class TokenId(str):
-    pass
+TokenId: TypeAlias = str
 
 
 @unique
 class TokenType(str, Enum):
-    access_token = "access_token"
-    refresh_token = "refresh_token"
+    ACCESS_TOKEN = "access_token"
+    REFRESH_TOKEN = "refresh_token"
 
 
 @dataclass
